@@ -1,4 +1,4 @@
-use super::{create_rev_prompt, Action, OpTrait};
+use super::{create_prompt_with_default, selected_rev, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, prompt::PromptData, state::State, term::Term, Res};
 use derive_more::Display;
 use std::{ffi::OsString, process::Command, rc::Rc};
@@ -6,12 +6,16 @@ use tui_prompts::State as _;
 
 pub(crate) const ARGS: &[Arg] = &[];
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Checkout branch/revision")]
 pub(crate) struct Checkout;
 impl OpTrait for Checkout {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_rev_prompt("Checkout", checkout))
+        Some(create_prompt_with_default(
+            "Checkout",
+            checkout,
+            selected_rev,
+        ))
     }
 }
 
@@ -25,7 +29,7 @@ fn checkout(state: &mut State, term: &mut Term, args: &[OsString], rev: &str) ->
     Ok(())
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Checkout new branch")]
 pub(crate) struct CheckoutNewBranch;
 impl OpTrait for CheckoutNewBranch {
