@@ -1,4 +1,4 @@
-use super::{create_rev_prompt, Action, OpTrait};
+use super::{create_prompt_with_default, selected_rev, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, screen, state::State, term::Term, Res};
 use derive_more::Display;
 use git2::Oid;
@@ -6,7 +6,7 @@ use std::{ffi::OsString, rc::Rc};
 
 pub(crate) const ARGS: &[Arg] = &[];
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Log current")]
 pub(crate) struct LogCurrent;
 impl OpTrait for LogCurrent {
@@ -18,12 +18,16 @@ impl OpTrait for LogCurrent {
     }
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Log other")]
 pub(crate) struct LogOther;
 impl OpTrait for LogOther {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_rev_prompt("Log rev", log_other))
+        Some(create_prompt_with_default(
+            "Log rev",
+            log_other,
+            selected_rev,
+        ))
     }
 }
 
