@@ -1,4 +1,4 @@
-use super::{create_rev_prompt, Action, OpTrait};
+use super::{create_prompt_with_default, selected_rev, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Res};
 use derive_more::Display;
 use std::{
@@ -9,7 +9,7 @@ use std::{
 
 pub(crate) const ARGS: &[Arg] = &[
     Arg::new("--keep-empty", "Keep empty commits", false),
-    Arg::new("--preserve-merges", "Presere merges", false),
+    Arg::new("--preserve-merges", "Preserve merges", false),
     Arg::new(
         "--committer-date-is-author-date",
         "Lie about committer date",
@@ -21,7 +21,7 @@ pub(crate) const ARGS: &[Arg] = &[
     Arg::new("--no-verify", "Disable hooks", false),
 ];
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Rebase continue")]
 pub(crate) struct RebaseContinue;
 impl OpTrait for RebaseContinue {
@@ -36,7 +36,7 @@ impl OpTrait for RebaseContinue {
     }
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Rebase abort")]
 pub(crate) struct RebaseAbort;
 impl OpTrait for RebaseAbort {
@@ -51,12 +51,16 @@ impl OpTrait for RebaseAbort {
     }
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Rebase elsewhere")]
 pub(crate) struct RebaseElsewhere;
 impl OpTrait for RebaseElsewhere {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
-        Some(create_rev_prompt("Rebase onto", rebase_elsewhere))
+        Some(create_prompt_with_default(
+            "Rebase onto",
+            rebase_elsewhere,
+            selected_rev,
+        ))
     }
 }
 
@@ -70,7 +74,7 @@ fn rebase_elsewhere(state: &mut State, term: &mut Term, args: &[OsString], rev:
     Ok(())
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Rebase interactive")]
 pub(crate) struct RebaseInteractive;
 impl OpTrait for RebaseInteractive {
@@ -107,7 +111,7 @@ fn parent(reference: &OsStr) -> OsString {
     parent
 }
 
-#[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
+#[derive(Display)]
 #[display(fmt = "Rebase autosquash")]
 pub(crate) struct RebaseAutosquash;
 impl OpTrait for RebaseAutosquash {
