@@ -8,6 +8,7 @@ use std::rc::Rc;
 use std::sync::Arc;
 use std::sync::RwLock;
 
+use arboard::Clipboard;
 use crossterm::event;
 use crossterm::event::Event;
 use crossterm::event::KeyCode;
@@ -20,6 +21,8 @@ use tui_prompts::Status;
 
 use crate::bindings::Bindings;
 use crate::cli;
+use crate::cmd_log::CmdLog;
+use crate::cmd_log::CmdLogEntry;
 use crate::config::Config;
 use crate::menu::Menu;
 use crate::menu::PendingMenu;
@@ -31,8 +34,6 @@ use crate::term;
 use crate::term::Term;
 use crate::ui;
 
-use super::command_args;
-use super::CmdLogEntry;
 use super::Res;
 
 pub(crate) struct State {
@@ -45,20 +46,19 @@ pub(crate) struct State {
     pub pending_menu: Option<PendingMenu>,
     pub pending_cmd: Option<(Child, Arc<RwLock<CmdLogEntry>>)>,
     enable_async_cmds: bool,
-    pub current_cmd_log_entries: Vec<Arc<RwLock<CmdLogEntry>>>,
+    pub current_cmd_log: CmdLog,
     pub prompt: prompt::Prompt,
+    pub clipboard: Option<Clipboard>,
 }
 
 impl State {
     pub fn create(
-        repo: Repository,
+        repo: Rc<Repository>,
         size: Rect,
         args: &cli::Args,
-        config: Config,
+        config: Rc<Config>,
         enable_async_cmds: bool,
     ) -> Res<Self> {
-        let repo = Rc::new(repo);
-        let config = Rc::new(config);
         let screens = match args.command {
             Some(cli::Commands::Show { ref reference }) => {
                 vec![screen::show::create(
@@ -78,6 +78,10 @@ impl State {
         let bindings = Bindings::from(&config.bindings);
         let pending_menu = root_menu(&config).map(PendingMenu::init);
 
+        let clipboard = Clipboard::new()
+            .inspect_err(|e| log::warn!("Couldn't initialize clipboard: {}", e))
+            .ok();
+
         Ok(Self {
             repo,
             config,
@@ -88,8 +92,9 @@ impl State {
             screens,
             pending_cmd: None,
             pending_menu,
-            current_cmd_log_entries: vec![],
+            current_cmd_log: CmdLog::new(),
             prompt: prompt::Prompt::new(),
+            clipboard,
         })
     }
 
@@ -106,7 +111,7 @@ impl State {
                         self.prompt.state.handle_key_event(key)
                     } else if key.kind == KeyEventKind::Press {
                         if self.pending_cmd.is_none() {
-                            self.current_cmd_log_entries.clear();
+                            self.current_cmd_log.clear();
                         }
 
                         self.handle_key_input(term, key)?;
@@ -145,8 +150,8 @@ impl State {
                     }
                 }
                 Err(error) => self
-                    .current_cmd_log_entries
-                    .push(Arc::new(RwLock::new(CmdLogEntry::Error(error.to_string())))),
+                    .current_cmd_log
+                    .push(CmdLogEntry::Error(error.to_string())),
             }
         }
 
@@ -196,8 +201,8 @@ impl State {
         match result {
             Ok(value) => Some(value),
             Err(error) => {
-                self.current_cmd_log_entries
-                    .push(Arc::new(RwLock::new(CmdLogEntry::Error(error.to_string()))));
+                self.current_cmd_log
+                    .push(CmdLogEntry::Error(error.to_string()));
 
                 None
             }
@@ -220,6 +225,16 @@ impl State {
         self.screens.last().expect("No screen")
     }
 
+    /// Displays an `Info` message to the CmdLog.
+    pub fn display_info(&mut self, message: String) {
+        self.current_cmd_log.push(CmdLogEntry::Info(message));
+    }
+
+    /// Displays an `Error` message to the CmdLog.
+    pub fn display_error(&mut self, error: String) {
+        self.current_cmd_log.push(CmdLogEntry::Error(error));
+    }
+
     /// Runs a `Command` and handles its output.
     /// Will block awaiting its completion.
     pub fn run_cmd(&mut self, term: &mut Term, input: &[u8], cmd: Command) -> Res<()> {
@@ -242,13 +257,7 @@ impl State {
         cmd.stdout(Stdio::piped());
         cmd.stderr(Stdio::piped());
 
-        let display = command_args(&cmd);
-
-        let log_entry = Arc::new(RwLock::new(CmdLogEntry::Cmd {
-            args: display,
-            out: None,
-        }));
-        self.current_cmd_log_entries.push(Arc::clone(&log_entry));
+        let log_entry = self.current_cmd_log.push_cmd(&cmd);
         term.draw(|frame| ui::ui(frame, self))?;
 
         let mut child = cmd.spawn()?;
@@ -303,16 +312,11 @@ impl State {
         let child = cmd.spawn()?;
 
         let out = child.wait_with_output()?;
+        let out_utf8 = String::from_utf8(out.stderr.clone())
+            .expect("Error turning command output to String")
+            .into();
 
-        self.current_cmd_log_entries
-            .push(Arc::new(RwLock::new(CmdLogEntry::Cmd {
-                args: command_args(&cmd),
-                out: Some(
-                    String::from_utf8(out.stderr.clone())
-                        .expect("Error turning command output to String")
-                        .into(),
-                ),
-            })));
+        self.current_cmd_log.push_cmd_with_output(&cmd, out_utf8);
 
         // Prevents cursor flash when exiting editor
         term.hide_cursor()?;
